pilas.municion.BalaDoble

Package pilas :: Module municion :: Class BalaDoble |
[hide private]
[frames] | no frames]

# Class BalaDoble

source code

    object --+
             |
      Municion --+
                 |
                BalaDoble

Munición que dispara 2 balas paralelas.

Instance Methods | [hide private]
__init__(self, separacion=10) Construye la Munición. | source code
disparar(self, x, y, rotacion, angulo_de_movimiento, offset_disparo_x, offset_disparo_y) Realiza un disparo. | source code
Inherited from `Municion`: `agregar_proyectil`, `get_proyectiles` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `Municion`: `proyectiles` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, separacion=10) (Constructor) | source code
Construye la Munición. :param separacion: Separación en pixeles entre los dos proyectiles. Overrides: object.__init__

### disparar(self, x, y, rotacion, angulo_de_movimiento, offset_disparo_x, offset_disparo_y) | source code
Realiza un disparo. :param x: Posición horizontal desde donde comenzará a disparar. :param y: Posición vertical desde donde comenzará a disparar. :param angulo_de_movimiento: Angulo de inclinación inicial del disparo. :param offset_disparo_x: Desplazamiento del disparo horizontal. :param offset_disparo_y: Desplazamiento del disparo vertical. Overrides: Municion.disparar